@@ -10,6 +10,7 @@ from sklearn.metrics import accuracy_score
 from .eval_tools.metrics import AverageMeter, accuracy
 from ..callbacks import callbacks
 from .eval_tools import classification_report
+from ..utils import log, file_utils
 
 
 class AccuracyRecorder(callbacks.Callback):
@@ -27,6 +28,8 @@ class AccuracyRecorder(callbacks.Callback):
         self.test_top1 = AverageMeter()
         self.true_labels = np.ones(0)
         self.pred_labels = np.ones(0)
+        self.logger = log.get_logger()
+
 
     def on_epoch_begin(self, epoch, logs: dict = {}):
         self.train_top1.reset()
@@ -43,7 +46,7 @@ class AccuracyRecorder(callbacks.Callback):
                                                                  target_names=self.target_names)
         # confuse_file = os.path.join(self.log_root, "confusion_matrix.csv")
         # conf_matrix = classification_report.get_confusion_matrix(true_labels, pred_labels, None, confuse_file)
-        print("\nAcc:{:.4f}\n{}".format(acc, report))
+        self.logger.info("\nAcc:{:.4f}\n{}".format(acc, report))
 
     @staticmethod
     def summary(phase, average_meter: AverageMeter, indicator, inputs, outputs, logs: dict = {}):
